<?php
// $Id:lingotek.admin.inc,LingoTek$
/**
 * @file
 * Administrative Settings for the module
 */

include_once('lingotek.session.inc');

/*
 * hook_settings_page
 *
 * Get the form for the administration page
 */
function lingotek_settings_page() {
  return drupal_get_form('lingotek_administrative_settings_form');
}

/*
 * Admistration Form for configuring the Lingotek Module.
 */
function lingotek_administrative_settings_form() {

  preg_match('.Revision: (\d+) .', '$Revision: 21829 $', $revision);

  //Authentication Settings
    $form['auth'] = array(
      '#type' => 'fieldset',
      '#title' => t('Authentication Settings'),
      '#description' => 'Lingotek Module Version 7.' . $revision[1] . '<br />Logging in: ' . lingotek_can_log_in()
    );

    $form['auth']['lingotek_login_id'] = array(
      '#type' => 'textfield',
      '#title' => t('Login ID'),
      '#description' => t('During flow of control, sometimes a Dashboard login id is not available.  In such instances, this login id will be used.  The only restriction is that the login id must exist in the Dashboard.'),
      '#default_value' => variable_get('lingotek_login_id', ''),
    );

    $form['auth']['lingotek_login_key'] = array(
      '#type' => 'textfield',
      '#title' => t('Login Key'),
      '#description' => t('Key to use when encrypting and decrypting the text.  The key must be generated by the Lingotek system.'),
      '#default_value' => variable_get('lingotek_login_key', ''),
    );
    $form['auth']['lingotek_url'] = array(
      '#type' => 'textfield',
      '#title' => t('Lingotek URL'),
      '#description' => t('URL pointing to the Lingotek instance to be used.'),
      '#default_value' => variable_get('lingotek_url', 'http://cms.lingotek.com'),
    );
    $form['auth']['lingotek_community'] = array(
      '#type' => 'textfield',
      '#title' => t('Community ID'),
      '#description' => t('Community ID in which the project exists and translations will be made.  This should be the id, not the community name.'),
      '#default_value' => variable_get('lingotek_community', ''),
    );

  //Dashboard Settings
    $form['dash'] = array('#type' => 'fieldset', '#title' => t('Dashboard Settings'));

    //If projects are available from Lingotek because the above login credentials worked, then display them in a drop list instead of a text box for the Id
    $projects = lingotek_get_projects();
    if (count($projects) == 0) {
      $form['dash']['#description'] ='Save your Authentication Settings first.  Then you can select projects and vaults by name instead of ID.';
      $form['dash']['lingotek_project'] = array(
        '#type' => 'textfield',
        '#title' => t('Project ID'),
        '#description' => t('Project id under which the translations will exist.'),
        '#default_value' => variable_get('lingotek_project', ''),
      );
    }
    else {
      $form['dash']['lingotek_project'] = array(
        '#type' => 'select',
        '#title' => t('Project'),
        '#options' => $projects,
        '#description' => t('Project under which the translations will exist.'),
        '#default_value' => variable_get('lingotek_project', ''),
      );
    }

    //If vaults are available from Lingotek because the above login credentials worked, then display them in a drop list instead of a text box for the Id
    $vaults = lingotek_get_vaults();
    $warning = t('If you want to use Machine Translation, then don\'t use the public vault and you need to add the selected vault to the project within the Lingotek Dashboard.');
    if (count($vaults) == 0) {
      $form['dash']['lingotek_vault'] = array(
        '#type' => 'textfield',
        '#title' => t('Vault ID'),
        '#description' => t('Vault id under which the translations will exist. (1 is typically the public vault.)') . ' ' . $warning,
        '#default_value' => variable_get('lingotek_vault', 1),
      );
    }
    else {
      $form['dash']['lingotek_vault'] = array(
        '#type' => 'select',
        '#title' => t('Vault'),
        '#options' => $vaults,
        '#description' => t('Vault where translations are saved.') . ' ' . $warning,
        '#default_value' => variable_get('lingotek_vault', 1),
      );
    }

  //Options
    $options = array();
    $options[FALSE] = t("Disabled");
    $options[TRUE] = t("Enabled");

  //Default Settings
    $form['defaults'] = array('#type' => 'fieldset', '#title' => t('Page Default Settings'));

    $form['defaults']['lingotek_phase_template'] = array(
      '#type' => 'select',
      '#title' => t('Phase Template (Workflow)'),
      '#description' => t('Use this phase template as the default when creating new pages.'),
      '#options' => lingotek_get_phase_templates(),
      '#default_value' => variable_get('lingotek_phase_template', ''),
    );

    $form['defaults']['lingotek_sync'] = array(
      '#type' => 'radios',
      '#title' => t('Synchronization Method'),
      '#description' => t('Use this synchronization method as the default when creating new pages.'),
      '#options' => lingotek_get_sync_methods(),
      '#default_value' => variable_get('lingotek_sync', FALSE),
    );

    $form['defaults']['lingotek_use_source'] = array(
      '#type' => 'select',
      '#title' => t('Include source text in synchronization.'),
      '#description' => t('Should the synchronization include the source language when a translation isn\'t provided?'),
      '#options' => $options,
      '#default_value' => variable_get('lingotek_use_source', TRUE),
    );

    $engines = lingotek_get_machine_translation_engines();
    $form['defaults']['lingotek_mt_engine'] = array(
      '#type' => 'select',
      '#title' => t('Machine Translation Engine'),
      '#description' => t('Choose which translation engine should be used for the automatically pasted translations.'),
      '#options' => $engines,
      '#default_value' => variable_get('lingotek_mt_engine', FALSE),
    );
    $form['defaults']['lingotek_available_mt_options'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Available Machine Translation Options'),
      '#description' => t('Choose which engines are available to the page creator.'),
      '#options' => $engines,
      '#default_value' => variable_get('lingotek_available_mt_options', array_keys($engines)),
    );

  //Developer Settings
    $form['developer_settings'] = array('#type' => 'fieldset', '#title' => t('Developer Settings'));

    $form['developer_settings']['lingotek_error_log'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable Error Log'),
      '#description' => t('This prints errors and warnings to the web server\'s error logs in addition to adding them to watchdog.'),
      '#default_value' => variable_get('lingotek_error_log', FALSE),
    );

  return system_settings_form($form);
}
